==> activiti-bpmn-converter-5.15-sources.jar: org/activiti/bpmn/converter/ManualTaskXMLConverter.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.activiti.bpmn.converter;

import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import org.activiti.bpmn.converter.util.BpmnXMLUtil;
import org.activiti.bpmn.model.BaseElement;
import org.activiti.bpmn.model.ManualTask;

/**
 * @author Tijs Rademakers
 */
public class ManualTaskXMLConverter extends BaseBpmnXMLConverter {

  public static String getXMLType() {
    return ELEMENT_TASK_MANUAL;
  }
  
  public static Class<? extends BaseElement> getBpmnElementType() {
    return ManualTask.class;
  }
  
  @Override
  protected String getXMLElementName() {
    return ELEMENT_TASK_MANUAL;
  }
  
  @Override
  protected BaseElement convertXMLToElement(XMLStreamReader xtr) throws Exception {
    ManualTask manualTask = new ManualTask();
    BpmnXMLUtil.addXMLLocation(manualTask, xtr);
    parseChildElements(getXMLElementName(), manualTask, xtr);
    return manualTask;
  }

  @Override
  protected void writeAdditionalAttributes(BaseElement element, XMLStreamWriter xtw) throws Exception {
  }
  
  @Override
  protected void writeExtensionChildElements(BaseElement element, XMLStreamWriter xtw) throws Exception {
  }

  @Override
  protected void writeAdditionalChildElements(BaseElement element, XMLStreamWriter xtw) throws Exception {
    
  }
}

==> activiti-bpmn-converter-5.23.0-sources.jar: org/activiti/bpmn/converter/ManualTaskXMLConverter.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.activiti.bpmn.converter;

import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import org.activiti.bpmn.converter.util.BpmnXMLUtil;
import org.activiti.bpmn.model.BaseElement;
import org.activiti.bpmn.model.BpmnModel;
import org.activiti.bpmn.model.ManualTask;

/**
 * @author Tijs Rademakers
 */
public class ManualTaskXMLConverter extends BaseBpmnXMLConverter {

  public Class<? extends BaseElement> getBpmnElementType() {
    return ManualTask.class;
  }
  
  @Override
  protected String getXMLElementName() {
    return ELEMENT_TASK_MANUAL;
  }
  
  @Override
  protected BaseElement convertXMLToElement(XMLStreamReader xtr, BpmnModel model) throws Exception {
    ManualTask manualTask = new ManualTask();
    BpmnXMLUtil.addXMLLocation(manualTask, xtr);
    parseChildElements(getXMLElementName(), manualTask, model, xtr);
    return manualTask;
  }

  @Override
  protected void writeAdditionalAttributes(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
  }
  
  @Override
  protected void writeAdditionalChildElements(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
    
  }
}
